@@ -1,5 +1,6 @@
 import logging
 import time
+import math
 from pathlib import Path
 from typing import Any, Iterator, List, Optional, Union
 
@@ -10,7 +11,7 @@ from RPA.core import geometry
 from RPA.core.geometry import Region
 
 
-DEFAULT_CONFIDENCE = 95.0
+DEFAULT_CONFIDENCE = 80.0
 LIMIT_FAILSAFE = 256
 
 logger = logging.getLogger(__name__)
@@ -21,6 +22,15 @@ def clamp(minimum, value, maximum):
     return max(minimum, min(value, maximum))
 
 
+def log2lin(minimum, value, maximum):
+    """Maps logarithmic scale to linear scale of same range."""
+    assert value >= minimum
+    assert value <= maximum
+    return (maximum - minimum) * (math.log(value) - math.log(minimum)) / (
+        math.log(maximum) - math.log(minimum)
+    ) + minimum
+
+
 class ImageNotFoundError(Exception):
     """Raised when template matching fails."""
 
@@ -38,7 +48,7 @@ def find(
     :param template:    Path to image or Image instance, used to search with
     :param limit:       Limit returned results to maximum of `limit`.
     :param region:      Area to search from. Can speed up search significantly.
-    :param confidence:  Confidence for matching, value between 0 and 100
+    :param confidence:  Confidence for matching, value between 1 and 100
     :return:            List of matching regions
     :raises ImageNotFoundError: No match was found
     """
@@ -46,6 +56,9 @@ def find(
     image = _to_image(image)
     template = _to_image(template)
 
+    # Convert confidence value to tolerance
+    tolerance = _to_tolerance(confidence)
+
     # Crop image if requested
     if region is not None:
         region = geometry.to_region(region)
@@ -59,7 +72,7 @@ def find(
     start = time.time()
 
     matches = []
-    for match in _match_template(image, template, confidence):
+    for match in _match_template(image, template, tolerance):
         matches.append(match)
         if limit is not None and len(matches) >= int(limit):
             break
@@ -87,14 +100,26 @@ def _to_image(obj: Any) -> Image.Image:
     return Image.open(obj)
 
 
+def _to_tolerance(confidence):
+    """Convert confidence value to tolerance.
+
+    Confidence is a logarithmic scale from 1 to 100,
+    tolerance is a linear scale from 0.01 to 1.00.
+    """
+    value = float(confidence)
+    value = clamp(1, value, 100)
+    value = log2lin(1, value, 100)
+    value = value / 100.0
+    return value
+
+
 def _match_template(
-    image: Image.Image, template: Image.Image, confidence: float = DEFAULT_CONFIDENCE
+    image: Image.Image, template: Image.Image, tolerance: float
 ) -> Iterator[Region]:
     """Use opencv's matchTemplate() to slide the `template` over
     `image` to calculate correlation coefficients, and then
-    filter with a confidence to find all relevant global maximums.
+    filter with a tolerance to find all relevant global maximums.
     """
-    confidence = max(0.0, min(float(confidence), 100.0)) / 100.0
     template_width, template_height = template.size
 
     if image.mode == "RGBA":
@@ -117,7 +142,7 @@ def _match_template(
     while True:
         # The point (match_x, match_y) is the top-left of the best match
         _, match_coeff, _, (match_x, match_y) = cv2.minMaxLoc(coefficients)
-        if match_coeff < confidence:
+        if match_coeff < tolerance:
             break
 
         # Zero out values for a template-sized region around the best match
